"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ContainerBuilder_1 = require("./ContainerBuilder");
const types_1 = require("./types");
class Kernel {
    constructor(config) {
        this.config = config;
        this.ready = false;
    }
    initialize() {
        return __awaiter(this, void 0, void 0, function* () {
            this.container = yield ContainerBuilder_1.ContainerBuilder.build(this, this.config);
            this.container.getAll(types_1.default.Gateway);
            this.container.get(types_1.default.EventEmitter).on("gatewayConfigured", () => {
                const gateways = this.container.getAll(types_1.default.Gateway);
                if (!this.ready && gateways.filter((x) => !x.configuration).length === 0) {
                    this.ready = true;
                    this.container.get(types_1.default.EventEmitter).emit("ready");
                }
            });
        });
    }
    addGauge(name, help, labelNames = []) {
        const gateways = this.container.getAll(types_1.default.Gateway);
        if (gateways.length === 0) {
            throw new Error("No gateways to attach to.");
        }
        gateways.forEach((x) => x.addGauge(name, help, labelNames));
    }
    gatewaysCall(callback) {
        return this.container.getAll(types_1.default.Gateway).forEach(callback);
    }
}
exports.default = Kernel;
//# sourceMappingURL=Kernel.js.map